@@ -18,17 +18,19 @@ RULE_OWNER = 'user_id:%(user_id)s'
 RULE_ADMIN_OR_OWNER = 'rule:admin_or_owner'
 RULE_ADMIN_OR_CREDENTIAL_OWNER = (
     'rule:admin_required or '
-    '(rule:owner and user_id:%(target.credential.user_id)s)')
+    '(rule:owner and user_id:%(target.credential.user_id)s)'
+)
 RULE_ADMIN_OR_TARGET_DOMAIN = (
-    'rule:admin_required or '
-    'token.project.domain.id:%(target.domain.id)s')
+    'rule:admin_required or token.project.domain.id:%(target.domain.id)s'
+)
 RULE_ADMIN_OR_TARGET_PROJECT = (
-    'rule:admin_required or '
-    'project_id:%(target.project.id)s')
+    'rule:admin_required or project_id:%(target.project.id)s'
+)
 RULE_ADMIN_OR_TOKEN_SUBJECT = 'rule:admin_or_token_subject'  # nosec
 RULE_REVOKE_EVENT_OR_ADMIN = 'rule:revoke_event_or_admin'
 RULE_SERVICE_ADMIN_OR_TOKEN_SUBJECT = (
-    'rule:service_admin_or_token_subject')  # nosec
+    'rule:service_admin_or_token_subject'  # nosec
+)
 RULE_SERVICE_OR_ADMIN = 'rule:service_or_admin'
 RULE_TRUST_OWNER = 'user_id:%(trust.trustor_user_id)s'
 
@@ -48,44 +50,61 @@ SYSTEM_READER = 'role:reader and system_scope:all'
 SYSTEM_ADMIN = 'role:admin and system_scope:all'
 DOMAIN_READER = 'role:reader and domain_id:%(target.domain_id)s'
 RULE_SYSTEM_ADMIN_OR_OWNER = '(' + SYSTEM_ADMIN + ') or rule:owner'
-RULE_SYSTEM_READER_OR_OWNER = '(' + SYSTEM_READER + ') or rule:owner'
+ADMIN_OR_SYSTEM_READER_OR_OWNER = (
+    '(' + RULE_ADMIN_REQUIRED + ') or ' '(' + SYSTEM_READER + ') or rule:owner'
+)
 RULE_ADMIN_OR_SYSTEM_READER = 'rule:admin_required or (' + SYSTEM_READER + ')'
 
 # Credential and EC2 Credential policies
-SYSTEM_READER_OR_CRED_OWNER = (
+ADMIN_OR_SYSTEM_READER_OR_CRED_OWNER = (
+    '(' + RULE_ADMIN_REQUIRED + ') or '
     '(' + SYSTEM_READER + ') '
     'or user_id:%(target.credential.user_id)s'
 )
-SYSTEM_ADMIN_OR_CRED_OWNER = (
-    '(' + SYSTEM_ADMIN + ') '
-    'or user_id:%(target.credential.user_id)s'
+ADMIN_OR_CRED_OWNER = (
+    '(' + RULE_ADMIN_REQUIRED + ') ' 'or user_id:%(target.credential.user_id)s'
+)
+
+# This rule template is meant for restricting role assignments done by domain
+# managers. It is intended to restrict the roles a domain manager can assign or
+# revoke to a sensible default set while allowing overrides via policy file by
+# adjusting the corresponding rule definition.
+# For the default, any roles with higher-level privileges than "manager" (e.g.
+# "admin") must be omitted to avoid privilege escalation.
+DOMAIN_MANAGER_ALLOWED_ROLES = (
+    "'manager':%(target.role.name)s or "
+    "'member':%(target.role.name)s or "
+    "'reader':%(target.role.name)s"
 )
 
 rules = [
     policy.RuleDefault(
-        name='admin_required',
-        check_str='role:admin or is_admin:1'),
-    policy.RuleDefault(
-        name='service_role',
-        check_str='role:service'),
+        name='admin_required', check_str='role:admin or is_admin:1'
+    ),
+    policy.RuleDefault(name='service_role', check_str='role:service'),
     policy.RuleDefault(
         name='service_or_admin',
-        check_str='rule:admin_required or rule:service_role'),
+        check_str='rule:admin_required or rule:service_role',
+    ),
+    policy.RuleDefault(name='owner', check_str=RULE_OWNER),
     policy.RuleDefault(
-        name='owner',
-        check_str=RULE_OWNER),
+        name='admin_or_owner', check_str='rule:admin_required or rule:owner'
+    ),
     policy.RuleDefault(
-        name='admin_or_owner',
-        check_str='rule:admin_required or rule:owner'),
-    policy.RuleDefault(
-        name='token_subject',
-        check_str='user_id:%(target.token.user_id)s'),
+        name='token_subject', check_str='user_id:%(target.token.user_id)s'
+    ),
     policy.RuleDefault(
         name='admin_or_token_subject',
-        check_str='rule:admin_required or rule:token_subject'),
+        check_str='rule:admin_required or rule:token_subject',
+    ),
     policy.RuleDefault(
         name='service_admin_or_token_subject',
-        check_str='rule:service_or_admin or rule:token_subject'),
+        check_str='rule:service_or_admin or rule:token_subject',
+    ),
+    policy.RuleDefault(
+        name="domain_managed_target_role",
+        check_str=DOMAIN_MANAGER_ALLOWED_ROLES,
+    ),
 ]
 
 
