@@ -21,7 +21,6 @@ from keystone import exception
 from keystone.resource.backends import base
 from keystone.resource.backends import sql_model
 
-
 LOG = log.getLogger(__name__)
 
 
@@ -53,8 +52,7 @@ class Resource(base.ResourceDriverBase):
             query = session.query(sql_model.Project)
             query = query.filter_by(name=project_name)
             if domain_id is None:
-                query = query.filter_by(
-                    domain_id=base.NULL_DOMAIN_ID)
+                query = query.filter_by(domain_id=base.NULL_DOMAIN_ID)
             else:
                 query = query.filter_by(domain_id=domain_id)
             try:
@@ -75,13 +73,14 @@ class Resource(base.ResourceDriverBase):
         # filter_limit_query() below, which will remove the filter from the
         # hints (hence ensuring our substitution is not exposed to the caller).
         for f in hints.filters:
-            if (f['name'] == 'domain_id' and f['value'] is None):
+            if f['name'] == 'domain_id' and f['value'] is None:
                 f['value'] = base.NULL_DOMAIN_ID
         with sql.session_for_read() as session:
             query = session.query(sql_model.Project)
             query = query.filter(sql_model.Project.id != base.NULL_DOMAIN_ID)
-            project_refs = sql.filter_limit_query(sql_model.Project, query,
-                                                  hints)
+            project_refs = sql.filter_limit_query(
+                sql_model.Project, query, hints
+            )
             return [project_ref.to_dict() for project_ref in project_refs]
 
     def list_projects_from_ids(self, ids):
@@ -91,8 +90,11 @@ class Resource(base.ResourceDriverBase):
             with sql.session_for_read() as session:
                 query = session.query(sql_model.Project)
                 query = query.filter(sql_model.Project.id.in_(ids))
-                return [project_ref.to_dict() for project_ref in query.all()
-                        if not self._is_hidden_ref(project_ref)]
+                return [
+                    project_ref.to_dict()
+                    for project_ref in query.all()
+                    if not self._is_hidden_ref(project_ref)
+                ]
 
     def list_project_ids_from_domain_ids(self, domain_ids):
         if not domain_ids:
@@ -100,10 +102,12 @@ class Resource(base.ResourceDriverBase):
         else:
             with sql.session_for_read() as session:
                 query = session.query(sql_model.Project.id)
-                query = (
-                    query.filter(sql_model.Project.domain_id.in_(domain_ids)))
-                return [x.id for x in query.all()
-                        if not self._is_hidden_ref(x)]
+                query = query.filter(
+                    sql_model.Project.domain_id.in_(domain_ids)
+                )
+                return [
+                    x.id for x in query.all() if not self._is_hidden_ref(x)
+                ]
 
     def list_projects_in_domain(self, domain_id):
         with sql.session_for_read() as session:
@@ -113,7 +117,8 @@ class Resource(base.ResourceDriverBase):
                 raise exception.DomainNotFound(domain_id=domain_id)
             query = session.query(sql_model.Project)
             project_refs = query.filter(
-                sql_model.Project.domain_id == domain_id)
+                sql_model.Project.domain_id == domain_id
+            )
             return [project_ref.to_dict() for project_ref in project_refs]
 
     def list_projects_acting_as_domain(self, hints):
@@ -130,14 +135,16 @@ class Resource(base.ResourceDriverBase):
         with sql.session_for_read() as session:
             children = self._get_children(session, [project_id])
             subtree = []
-            examined = set([project_id])
+            examined = {project_id}
             while children:
                 children_ids = set()
                 for ref in children:
                     if ref['id'] in examined:
-                        msg = ('Circular reference or a repeated '
-                               'entry found in projects hierarchy - '
-                               '%(project_id)s.')
+                        msg = (
+                            'Circular reference or a repeated '
+                            'entry found in projects hierarchy - '
+                            '%(project_id)s.'
+                        )
                         LOG.error(msg, {'project_id': ref['id']})
                         return
                     children_ids.add(ref['id'])
@@ -154,15 +161,18 @@ class Resource(base.ResourceDriverBase):
             examined = set()
             while project.get('parent_id') is not None:
                 if project['id'] in examined:
-                    msg = ('Circular reference or a repeated '
-                           'entry found in projects hierarchy - '
-                           '%(project_id)s.')
+                    msg = (
+                        'Circular reference or a repeated '
+                        'entry found in projects hierarchy - '
+                        '%(project_id)s.'
+                    )
                     LOG.error(msg, {'project_id': project['id']})
                     return
 
                 examined.add(project['id'])
                 parent_project = self._get_project(
-                    session, project['parent_id']).to_dict()
+                    session, project['parent_id']
+                ).to_dict()
                 parents.append(parent_project)
                 project = parent_project
             return parents
@@ -178,7 +188,8 @@ class Resource(base.ResourceDriverBase):
             query = session.query(sql_model.ProjectTag)
             if 'tags' in filters.keys():
                 filtered_ids += self._filter_ids_by_tags(
-                    query, filters['tags'].split(','))
+                    query, filters['tags'].split(',')
+                )
             if 'tags-any' in filters.keys():
                 any_tags = filters['tags-any'].split(',')
                 subq = query.filter(sql_model.ProjectTag.name.in_(any_tags))
@@ -188,10 +199,11 @@ class Resource(base.ResourceDriverBase):
                 filtered_ids = any_tags
             if 'not-tags' in filters.keys():
                 blacklist_ids = self._filter_ids_by_tags(
-                    query, filters['not-tags'].split(','))
-                filtered_ids = self._filter_not_tags(session,
-                                                     filtered_ids,
-                                                     blacklist_ids)
+                    query, filters['not-tags'].split(',')
+                )
+                filtered_ids = self._filter_not_tags(
+                    session, filtered_ids, blacklist_ids
+                )
             if 'not-tags-any' in filters.keys():
                 any_tags = filters['not-tags-any'].split(',')
                 subq = query.filter(sql_model.ProjectTag.name.in_(any_tags))
@@ -199,22 +211,26 @@ class Resource(base.ResourceDriverBase):
                 if 'not-tags' in filters.keys():
                     filtered_ids += blacklist_ids
                 else:
-                    filtered_ids = self._filter_not_tags(session,
-                                                         filtered_ids,
-                                                         blacklist_ids)
+                    filtered_ids = self._filter_not_tags(
+                        session, filtered_ids, blacklist_ids
+                    )
             if not filtered_ids:
                 return []
             query = session.query(sql_model.Project)
             query = query.filter(sql_model.Project.id.in_(filtered_ids))
-            return [project_ref.to_dict() for project_ref in query.all()
-                    if not self._is_hidden_ref(project_ref)]
+            return [
+                project_ref.to_dict()
+                for project_ref in query.all()
+                if not self._is_hidden_ref(project_ref)
+            ]
 
     def _filter_ids_by_tags(self, query, tags):
         filtered_ids = []
         subq = query.filter(sql_model.ProjectTag.name.in_(tags))
         for ptag in subq:
-            subq_tags = query.filter(sql_model.ProjectTag.project_id ==
-                                     ptag['project_id'])
+            subq_tags = query.filter(
+                sql_model.ProjectTag.project_id == ptag['project_id']
+            )
             result = map(lambda x: x['name'], subq_tags.all())
             if set(tags) <= set(result):
                 filtered_ids.append(ptag['project_id'])
@@ -258,12 +274,16 @@ class Resource(base.ResourceDriverBase):
             # Move the "_resource_options" attribute over to the real ref
             # so that resource_options.resource_options_ref_to_mapper can
             # handle the work.
-            setattr(project_ref, '_resource_options',
-                    getattr(new_project, '_resource_options', {}))
+            setattr(
+                project_ref,
+                '_resource_options',
+                getattr(new_project, '_resource_options', {}),
+            )
 
             # Move options into the proper attribute mapper construct
             resource_options.resource_options_ref_to_mapper(
-                project_ref, sql_model.ProjectOption)
+                project_ref, sql_model.ProjectOption
+            )
             project_ref.extra = new_project.extra
             return project_ref.to_dict(include_extra_dict=True)
 
@@ -279,13 +299,18 @@ class Resource(base.ResourceDriverBase):
             return
         with sql.session_for_write() as session:
             query = session.query(sql_model.Project).filter(
-                sql_model.Project.id.in_(project_ids))
+                sql_model.Project.id.in_(project_ids)
+            )
             project_ids_from_bd = [p['id'] for p in query.all()]
             for project_id in project_ids:
-                if (project_id not in project_ids_from_bd or
-                        project_id == base.NULL_DOMAIN_ID):
-                    LOG.warning('Project %s does not exist and was not '
-                                'deleted.', project_id)
+                if (
+                    project_id not in project_ids_from_bd
+                    or project_id == base.NULL_DOMAIN_ID
+                ):
+                    LOG.warning(
+                        'Project %s does not exist and was not deleted.',
+                        project_id,
+                    )
             query.delete(synchronize_session=False)
 
     def check_project_depth(self, max_depth):
@@ -342,9 +367,9 @@ class Resource(base.ResourceDriverBase):
             for index in range(max_depth):
                 query = query.outerjoin(
                     obj_list[index + 1],
-                    obj_list[index].id == obj_list[index + 1].parent_id)
-            exceeded_lines = query.filter(
-                obj_list[-1].id != expression.null())
+                    obj_list[index].id == obj_list[index + 1].parent_id,
+                )
+            exceeded_lines = query.filter(obj_list[-1].id != expression.null())
 
             if exceeded_lines:
                 return [line[max_depth].id for line in exceeded_lines]
