@@ -12,9 +12,9 @@
 
 
 import datetime
+from unittest import mock
 import uuid
 
-import mock
 from oslo_utils import timeutils
 from testtools import matchers
 
@@ -27,8 +27,7 @@ from keystone.revoke.backends import sql
 from keystone.tests import unit
 from keystone.tests.unit import ksfixtures
 from keystone.tests.unit import test_backend_sql
-from keystone.token.providers import common
-
+from keystone.token import provider
 
 CONF = keystone.conf.CONF
 PROVIDERS = provider_api.ProviderAPIs
@@ -47,12 +46,14 @@ def _sample_blank_token():
     return token_data
 
 
-class RevokeTests(object):
+class RevokeTests:
 
     def _assertTokenRevoked(self, token_data):
-        self.assertRaises(exception.TokenNotFound,
-                          PROVIDERS.revoke_api.check_token,
-                          token=token_data)
+        self.assertRaises(
+            exception.TokenNotFound,
+            PROVIDERS.revoke_api.check_token,
+            token=token_data,
+        )
 
     def _assertTokenNotRevoked(self, token_data):
         self.assertIsNone(PROVIDERS.revoke_api.check_token(token_data))
@@ -134,11 +135,13 @@ class RevokeTests(object):
         # the token when passed in.
         first_token = _sample_blank_token()
         first_token['project_id'] = uuid.uuid4().hex
-        revocation_backend.revoke(revoke_model.RevokeEvent(
-            project_id=first_token['project_id']))
+        revocation_backend.revoke(
+            revoke_model.RevokeEvent(project_id=first_token['project_id'])
+        )
         self._assertTokenRevoked(first_token)
-        self.assertEqual(1, len(revocation_backend.list_events(
-            token=first_token)))
+        self.assertEqual(
+            1, len(revocation_backend.list_events(token=first_token))
+        )
 
         # Create a second token, revoke it, check the token has been revoked,
         # and check the list to make sure that even though we now have 2
@@ -146,11 +149,13 @@ class RevokeTests(object):
         # only one match for our second_token should exist
         second_token = _sample_blank_token()
         second_token['project_id'] = uuid.uuid4().hex
-        revocation_backend.revoke(revoke_model.RevokeEvent(
-            project_id=second_token['project_id']))
+        revocation_backend.revoke(
+            revoke_model.RevokeEvent(project_id=second_token['project_id'])
+        )
         self._assertTokenRevoked(second_token)
         self.assertEqual(
-            1, len(revocation_backend.list_events(token=second_token)))
+            1, len(revocation_backend.list_events(token=second_token))
+        )
 
         # This gets a token but overrides project_id of the token to be None.
         # We expect that since there are two events which both have populated
@@ -168,23 +173,27 @@ class RevokeTests(object):
         # check to make sure that list_events matches the token to the event we
         # just revoked.
         first_token = _sample_blank_token()
-        first_token['audit_id'] = common.random_urlsafe_str()
+        first_token['audit_id'] = provider.random_urlsafe_str()
         PROVIDERS.revoke_api.revoke_by_audit_id(
-            audit_id=first_token['audit_id'])
+            audit_id=first_token['audit_id']
+        )
         self._assertTokenRevoked(first_token)
         self.assertEqual(
-            1, len(revocation_backend.list_events(token=first_token)))
+            1, len(revocation_backend.list_events(token=first_token))
+        )
 
         # Create a second token, revoke it, check it is revoked, check to make
         # sure that list events only finds 1 match since there are 2 and they
         # dont both have different populated audit_id fields
         second_token = _sample_blank_token()
-        second_token['audit_id'] = common.random_urlsafe_str()
+        second_token['audit_id'] = provider.random_urlsafe_str()
         PROVIDERS.revoke_api.revoke_by_audit_id(
-            audit_id=second_token['audit_id'])
+            audit_id=second_token['audit_id']
+        )
         self._assertTokenRevoked(second_token)
         self.assertEqual(
-            1, len(revocation_backend.list_events(token=second_token)))
+            1, len(revocation_backend.list_events(token=second_token))
+        )
 
         # Create a third token with audit_id set to None to make sure that
         # since there are no events currently revoked with audit_id None this
@@ -193,7 +202,8 @@ class RevokeTests(object):
         third_token['audit_id'] = None
         self._assertTokenNotRevoked(third_token)
         self.assertEqual(
-            0, len(revocation_backend.list_events(token=third_token)))
+            0, len(revocation_backend.list_events(token=third_token))
+        )
 
     def test_list_revoked_since(self):
         revocation_backend = sql.Revoke()
@@ -212,42 +222,52 @@ class RevokeTests(object):
         first_token = _sample_blank_token()
         first_token['user_id'] = uuid.uuid4().hex
         first_token['project_id'] = uuid.uuid4().hex
-        first_token['audit_id'] = common.random_urlsafe_str()
+        first_token['audit_id'] = provider.random_urlsafe_str()
         # revoke event and then verify that there is only one revocation
         # and verify the only revoked event is the token
-        PROVIDERS.revoke_api.revoke(revoke_model.RevokeEvent(
-            user_id=first_token['user_id'],
-            project_id=first_token['project_id'],
-            audit_id=first_token['audit_id']))
+        PROVIDERS.revoke_api.revoke(
+            revoke_model.RevokeEvent(
+                user_id=first_token['user_id'],
+                project_id=first_token['project_id'],
+                audit_id=first_token['audit_id'],
+            )
+        )
         self._assertTokenRevoked(first_token)
         self.assertEqual(
-            1, len(revocation_backend.list_events(token=first_token)))
+            1, len(revocation_backend.list_events(token=first_token))
+        )
         # If a token has None values which the event contains it shouldn't
         # match and not be revoked
         second_token = _sample_blank_token()
         self._assertTokenNotRevoked(second_token)
         self.assertEqual(
-            0, len(revocation_backend.list_events(token=second_token)))
+            0, len(revocation_backend.list_events(token=second_token))
+        )
         # If an event column and corresponding dict value don't match, Then
         # it should not add the event in the list. Demonstrate for project
         third_token = _sample_blank_token()
         third_token['project_id'] = uuid.uuid4().hex
         self._assertTokenNotRevoked(third_token)
         self.assertEqual(
-            0, len(revocation_backend.list_events(token=third_token)))
+            0, len(revocation_backend.list_events(token=third_token))
+        )
         # A revoked event with user_id as null and token user_id non null
         # should still be return an event and be revoked if other non null
         # event fields match non null token fields
         fourth_token = _sample_blank_token()
         fourth_token['user_id'] = uuid.uuid4().hex
         fourth_token['project_id'] = uuid.uuid4().hex
-        fourth_token['audit_id'] = common.random_urlsafe_str()
-        PROVIDERS.revoke_api.revoke(revoke_model.RevokeEvent(
-            project_id=fourth_token['project_id'],
-            audit_id=fourth_token['audit_id']))
+        fourth_token['audit_id'] = provider.random_urlsafe_str()
+        PROVIDERS.revoke_api.revoke(
+            revoke_model.RevokeEvent(
+                project_id=fourth_token['project_id'],
+                audit_id=fourth_token['audit_id'],
+            )
+        )
         self._assertTokenRevoked(fourth_token)
         self.assertEqual(
-            1, len(revocation_backend.list_events(token=fourth_token)))
+            1, len(revocation_backend.list_events(token=fourth_token))
+        )
 
     def _user_field_test(self, field_name):
         token = _sample_blank_token()
@@ -279,7 +299,8 @@ class RevokeTests(object):
 
         self._assertTokenNotRevoked(token_data)
         self.assertEqual(
-            0, len(revocation_backend.list_events(token=token_data)))
+            0, len(revocation_backend.list_events(token=token_data))
+        )
 
         PROVIDERS.revoke_api.revoke(
             revoke_model.RevokeEvent(domain_id=domain_id)
@@ -287,7 +308,8 @@ class RevokeTests(object):
 
         self._assertTokenRevoked(token_data)
         self.assertEqual(
-            1, len(revocation_backend.list_events(token=token_data)))
+            1, len(revocation_backend.list_events(token=token_data))
+        )
 
     def test_by_domain_project(self):
         revocation_backend = sql.Revoke()
@@ -300,16 +322,21 @@ class RevokeTests(object):
 
         self._assertTokenNotRevoked(token_data)
         self.assertEqual(
-            0, len(revocation_backend.list_events(token=token_data)))
+            0, len(revocation_backend.list_events(token=token_data))
+        )
 
         # If revoke a domain, then a token scoped to a project in the domain
         # is revoked.
-        PROVIDERS.revoke_api.revoke(revoke_model.RevokeEvent(
-            domain_id=token_data['assignment_domain_id']))
+        PROVIDERS.revoke_api.revoke(
+            revoke_model.RevokeEvent(
+                domain_id=token_data['assignment_domain_id']
+            )
+        )
 
         self._assertTokenRevoked(token_data)
         self.assertEqual(
-            1, len(revocation_backend.list_events(token=token_data)))
+            1, len(revocation_backend.list_events(token=token_data))
+        )
 
     def test_by_domain_domain(self):
         revocation_backend = sql.Revoke()
@@ -321,46 +348,20 @@ class RevokeTests(object):
 
         self._assertTokenNotRevoked(token_data)
         self.assertEqual(
-            0, len(revocation_backend.list_events(token=token_data)))
+            0, len(revocation_backend.list_events(token=token_data))
+        )
 
         # If revoke a domain, then a token scoped to the domain is revoked.
-        PROVIDERS.revoke_api.revoke(revoke_model.RevokeEvent(
-            domain_id=token_data['assignment_domain_id']))
+        PROVIDERS.revoke_api.revoke(
+            revoke_model.RevokeEvent(
+                domain_id=token_data['assignment_domain_id']
+            )
+        )
 
         self._assertTokenRevoked(token_data)
         self.assertEqual(
-            1, len(revocation_backend.list_events(token=token_data)))
-
-    def test_by_project_and_user_and_role(self):
-        revocation_backend = sql.Revoke()
-
-        first_token = _sample_blank_token()
-        first_token['user_id'] = uuid.uuid4().hex
-        first_token['project_id'] = uuid.uuid4().hex
-
-        second_token = _sample_blank_token()
-        second_token['user_id'] = uuid.uuid4().hex
-        second_token['project_id'] = first_token['project_id']
-
-        # Check that both tokens have not been revoked.
-        self._assertTokenNotRevoked(first_token)
-        self._assertTokenNotRevoked(second_token)
-        self.assertEqual(
-            0, len(revocation_backend.list_events(token=first_token)))
-        self.assertEqual(
-            0, len(revocation_backend.list_events(token=second_token)))
-
-        # Revoke first_token using user_id and project_id
-        PROVIDERS.revoke_api.revoke_by_user_and_project(
-            first_token['user_id'], first_token['project_id'])
-
-        # Check that only first_token has been revoked.
-        self._assertTokenRevoked(first_token)
-        self._assertTokenNotRevoked(second_token)
-        self.assertEqual(
-            1, len(revocation_backend.list_events(token=first_token)))
-        self.assertEqual(
-            0, len(revocation_backend.list_events(token=second_token)))
+            1, len(revocation_backend.list_events(token=token_data))
+        )
 
     def test_revoke_by_audit_id(self):
         token = _sample_blank_token()
@@ -380,7 +381,7 @@ class RevokeTests(object):
         revocation_backend = sql.Revoke()
 
         # Create our first token with audit_id
-        audit_id = common.build_audit_info(parent_audit_id=None)[0]
+        audit_id = provider.random_urlsafe_str()
         token = _sample_blank_token()
         # Audit ID and Audit Chain ID are populated with the same value
         # if the token is an original token
@@ -400,11 +401,12 @@ class RevokeTests(object):
     def test_expired_events_are_removed(self, mock_utcnow):
         def _sample_token_values():
             token = _sample_blank_token()
-            token['expires_at'] = utils.isotime(_future_time(),
-                                                subsecond=True)
+            token['expires_at'] = utils.isotime(_future_time(), subsecond=True)
             return token
 
-        now = datetime.datetime.utcnow()
+        # We can not use timeutils.utcnow directly since we mocked it, so use
+        # datetime to get pretty much the same.
+        now = datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
         now_plus_2h = now + datetime.timedelta(hours=2)
         mock_utcnow.return_value = now
 
@@ -415,18 +417,22 @@ class RevokeTests(object):
         audit_chain_id = uuid.uuid4().hex
         PROVIDERS.revoke_api.revoke_by_audit_chain_id(audit_chain_id)
         token_values['audit_chain_id'] = audit_chain_id
-        self.assertRaises(exception.TokenNotFound,
-                          PROVIDERS.revoke_api.check_token,
-                          token_values)
+        self.assertRaises(
+            exception.TokenNotFound,
+            PROVIDERS.revoke_api.check_token,
+            token_values,
+        )
 
         # Move our clock forward by 2h, build a new token and validate it.
         # 'synchronize' should now be exercised and remove old expired events
         mock_utcnow.return_value = now_plus_2h
         PROVIDERS.revoke_api.revoke_by_audit_chain_id(audit_chain_id)
         # two hours later, it should still be not found
-        self.assertRaises(exception.TokenNotFound,
-                          PROVIDERS.revoke_api.check_token,
-                          token_values)
+        self.assertRaises(
+            exception.TokenNotFound,
+            PROVIDERS.revoke_api.check_token,
+            token_values,
+        )
 
     def test_delete_group_without_role_does_not_revoke_users(self):
         revocation_backend = sql.Revoke()
@@ -456,7 +462,8 @@ class RevokeTests(object):
             user_id=user2['id'], group_id=group1['id']
         )
         self.assertEqual(
-            2, len(PROVIDERS.identity_api.list_users_in_group(group1['id'])))
+            2, len(PROVIDERS.identity_api.list_users_in_group(group1['id']))
+        )
         PROVIDERS.identity_api.delete_group(group1['id'])
         self.assertEqual(0, len(revocation_backend.list_events()))
 
@@ -478,31 +485,22 @@ class RevokeTests(object):
             user_id=user2['id'], group_id=group2['id']
         )
         self.assertEqual(
-            2, len(PROVIDERS.identity_api.list_users_in_group(group2['id'])))
+            2, len(PROVIDERS.identity_api.list_users_in_group(group2['id']))
+        )
         PROVIDERS.identity_api.delete_group(group2['id'])
         self.assertEqual(2, len(revocation_backend.list_events()))
 
 
-class UUIDSqlRevokeTests(test_backend_sql.SqlTests, RevokeTests):
-    def config_overrides(self):
-        super(UUIDSqlRevokeTests, self).config_overrides()
-        self.config_fixture.config(
-            group='token',
-            provider='uuid',
-            revoke_by_id=False)
-
-
 class FernetSqlRevokeTests(test_backend_sql.SqlTests, RevokeTests):
     def config_overrides(self):
-        super(FernetSqlRevokeTests, self).config_overrides()
+        super().config_overrides()
         self.config_fixture.config(
-            group='token',
-            provider='fernet',
-            revoke_by_id=False)
+            group='token', provider='fernet', revoke_by_id=False
+        )
         self.useFixture(
             ksfixtures.KeyRepository(
                 self.config_fixture,
                 'fernet_tokens',
-                CONF.fernet_tokens.max_active_keys
+                CONF.fernet_tokens.max_active_keys,
             )
         )
